
#ifndef _H_BASISDATEN_LOADED
#define _H_BASISDATEN_LOADED 1



#include "text_util.h"


class BasisDatenType : TextType
{
   public:
   BasisDatenType();
   ~BasisDatenType();

   bool BasisDatenLesen (  char *dateiname );

   bool BasisDatenSchreiben (  char *dateiname );


   bool BasisDatenReadInt (  char *id , int *wert );

   bool BasisDatenReadFloat ( char *id , float *wert );

   bool BasisDatenReadBool ( char *id , bool *wert );

   bool BasisDatenReadString ( char *id , char *wert );

   bool BasisDatenWriteInt (  char *id ,  int wert );

   bool BasisDatenWriteFloat ( char *id , float wert );

   bool BasisDatenWriteBool (  char *id , bool wert );

   bool BasisDatenWriteString (  char *id , char *wert );

private:
   char *locate_zeile(char *id,int *nummer);

   bool veraendert;		
   bool datei_gelesen;	
   char name[300];		

   		
} ;



#endif /* _BASISDATEN_LOADED */

